@@ -88,4 +88,11 @@ class OCP(base.Inspector):
                         result.append(ics['state'])
                 if reason == 'ImagePullBackOff':
                     result.append(ws)
+                if reason == 'CrashLoopBackOff':
+                    result.append(ws)
+                    state = cs['lastState']
+                    if 'terminated' in state:
+                        result.append(dict(
+                            message=state['terminated']['message']
+                        ))
         return result
