@@ -174,6 +174,33 @@ class TestOCP:
                     {'waiting': {'reason': 'ImagePullBackOff'}},
                 ]
             ),
+            (
+                dict(
+                    metadata=dict(name='test_pod'),
+                    status=dict(containerStatuses=[
+                        dict(
+                            name='test_container',
+                            ready=False,
+                            state=dict(
+                                waiting=dict(
+                                    reason='CrashLoopBackOff',
+                                    message="blah",
+                                ),
+                            ),
+                            lastState=dict(
+                                terminated=dict(
+                                    message="msg"
+                                )
+                            ),
+                        ),
+                    ]),
+                ),
+                [
+                    "Container 'test_container' in pod 'test_pod' is not ready",
+                    dict(reason="CrashLoopBackOff", message="blah"),
+                    dict(message="msg"),
+                ],
+            ),
             (
                 dict(
                     metadata=dict(name='test_pod'),
